# aara

## An arXiv Reading App

A super simple [Textual](https://github.com/Textualize/textual) application for reading the latest posts on the ArXiv.

# Installation

```
pip install aara
```

If you've cloned the repository, I'm using `uv` for package management, so running should be as simple as:

``` sh
uv run aara astro-ph
```

# Usage

``` python
aara <arXiv category>
# e.g. aara astro-ph
```